@@ -45,6 +45,10 @@ echo "MANILA_BACKEND2_CONFIG_GROUP_NAME=paris" >> $localconf
 echo "MANILA_SHARE_BACKEND1_NAME=LONDON" >> $localconf
 echo "MANILA_SHARE_BACKEND2_NAME=PARIS" >> $localconf
 
+echo "MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE=${MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE:=True}" >> $localconf
+
+echo "MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST=${MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST:=False}" >> $localconf
+
 # === Handle script arguments ===
 # First argument is expected to be a boolean-like value for DHSS.
 DHSS=$1
@@ -194,6 +198,7 @@ if [[ "$MANILA_SETUP_IPV6" == True ]]; then
     # regular Neutron DevStack configuration.
     echo "NEUTRON_CREATE_INITIAL_NETWORKS=False" >> $localconf
     echo "IP_VERSION=4+6" >> $localconf
+    echo "MANILA_RESTORE_IPV6_DEFAULT_ROUTE=False" >> $localconf
 fi
 
 if [[ "$DRIVER" == "generic"* ]]; then
