@@ -835,7 +835,7 @@ function start_manila_api {
 
     if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
         echo "Deploying with UWSGI"
-        run_process m-api "$MANILA_BIN_DIR/uwsgi --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
+        run_process m-api "$(which uwsgi) --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
     elif [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
         echo "Deploying with MOD_WSGI"
         install_apache_wsgi
@@ -917,6 +917,14 @@ function install_manila_tempest_plugin {
 # update_tempest - Function used for updating Tempest config if Tempest service enabled
 function update_tempest {
     if is_service_enabled tempest; then
+
+        if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
+            # The public network was created by us, so set it explicitly in
+            # tempest.conf
+            public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
+            iniset $TEMPEST_CONFIG network public_network_id $public_net_id
+        fi
+
         TEMPEST_CONFIG=${TEMPEST_CONFIG:-$TEMPEST_DIR/etc/tempest.conf}
         ADMIN_TENANT_NAME=${ADMIN_TENANT_NAME:-"admin"}
         ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
@@ -1011,10 +1019,41 @@ function install_libraries {
     fi
 }
 
+function allow_host_ports_for_share_mounting {
+
+    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ NFS ]]; then
+        # 111 and 2049 are for rpcbind and NFS
+        # Other ports are for NFSv3 statd, mountd and lockd daemons
+        MANILA_TCP_PORTS=(2049 111 32803 892 875 662)
+        MANILA_UDP_PORTS=(111 32769 892 875 662)
+    fi
+    if [[ $MANILA_ENABLED_SHARE_PROTOCOLS =~ CEPHFS ]]; then
+        # clients need access to the ceph daemons
+        MANILA_TCP_PORTS=(${MANILA_TCP_PORTS[*]} 6789 6800:7300)
+    fi
+
+    if [[ -v MANILA_TCP_PORTS || -v MANILA_UDP_PORTS ]]; then
+        for ipcmd in iptables ip6tables; do
+            sudo $ipcmd -N manila-storage
+            sudo $ipcmd -I INPUT 1 -j manila-storage
+            for port in ${MANILA_TCP_PORTS[*]}; do
+                sudo $ipcmd -A manila-storage -m tcp -p tcp --dport $port -j ACCEPT
+            done
+            for port in ${MANILA_UDP_PORTS[*]}; do
+                sudo $ipcmd -A manila-storage -m udp -p udp --dport $port -j ACCEPT
+            done
+        done
+    fi
+}
+
 function setup_ipv6 {
 
-    # save IPv6 default route to add back later after enabling forwarding
-    local default_route=$(ip -6 route | grep default | cut -d ' ' -f1,2,3,4,5)
+    # This will fail with multiple default routes and is not needed in CI
+    # but may be useful when developing with devstack locally
+    if [ $(trueorfalse False MANILA_RESTORE_IPV6_DEFAULT_ROUTE) == True ]; then
+        # save IPv6 default route to add back later after enabling forwarding
+        local default_route=$(ip -6 route | grep default | cut -d ' ' -f1,2,3,4,5)
+    fi
 
     # make sure those system values are set
     sudo sysctl -w net.ipv6.conf.lo.disable_ipv6=0
@@ -1130,15 +1169,27 @@ function setup_ipv6 {
     # log the systemd status
     sudo systemctl status $QUAGGA_SERVICES
 
-    # add default IPv6 route back
-    if ! [[ -z $default_route ]]; then
-        # "replace" should ignore "RTNETLINK answers: File exists"
-        # error if the route wasn't flushed by the bgp setup we did earlier.
-        sudo ip -6 route replace $default_route
+    # This will fail with mutltiple default routes and is not needed in CI
+    # but may be useful when developing with devstack locally
+    if [ $(trueorfalse False MANILA_RESTORE_IPV6_DEFAULT_ROUTE) == True ]; then
+        # add default IPv6 route back
+        if ! [[ -z $default_route ]]; then
+            # "replace" should ignore "RTNETLINK answers: File exists"
+            # error if the route wasn't flushed by the bgp setup we did earlier.
+            sudo ip -6 route replace $default_route
+        fi
     fi
 
 }
 
+function setup_bgp_for_ipv6 {
+    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
+    neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
+    neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
+    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
+    neutron bgp-speaker-peer-add bgpspeaker bgppeer
+}
+
 # Main dispatcher
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing Manila Client"
@@ -1237,10 +1288,32 @@ elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
     fi
     ###########################################################################
 
-    echo_summary "Fetching and installing manila-tempest-plugin system-wide"
-    install_manila_tempest_plugin
+
+    if [ $(trueorfalse False MANILA_INSTALL_TEMPEST_PLUGIN_SYSTEMWIDE) == True ]; then
+        echo_summary "Fetching and installing manila-tempest-plugin system-wide"
+        install_manila_tempest_plugin
+        export DEPRECATED_TEXT="$DEPRECATED_TEXT\nInstalling
+        manila-tempest-plugin can be done with the help of its own DevStack
+        plugin by adding: \n\n\t'enable_plugin manila-tempest-plugin
+        https://opendev.org/openstack/manila-tempest-plugin'.\n\nManila's
+        DevStack plugin will stop installing it automatically."
+    fi
+
     echo_summary "Update Tempest config"
     update_tempest
+
+
+    if [[ "$(trueorfalse False MANILA_ALLOW_NAS_SERVER_PORTS_ON_HOST)" == "True" ]]; then
+        echo_summary "Allowing IPv4 and IPv6 access to NAS ports on the host"
+        allow_host_ports_for_share_mounting
+    fi
+
+    if [[ "$(trueorfalse False MANILA_SETUP_IPV6)" == "True" ]]; then
+        # Now that all plugins are loaded, setup BGP
+        echo_summary "Setting up BGP speaker to advertise routes to project networks"
+        setup_bgp_for_ipv6
+    fi
+
 fi
 
 if [[ "$1" == "unstack" ]]; then
