@@ -318,7 +318,7 @@ class Share(BASE, ManilaBase):
     task_state = Column(String(255))
     instances = orm.relationship(
         "ShareInstance",
-        lazy='immediate',
+        lazy='subquery',
         primaryjoin=(
             'and_('
             'Share.id == ShareInstance.share_id, '
@@ -388,7 +388,7 @@ class ShareInstance(BASE, ManilaBase):
                                   nullable=True)
     _availability_zone = orm.relationship(
         "AvailabilityZone",
-        lazy='immediate',
+        lazy='subquery',
         foreign_keys=availability_zone_id,
         primaryjoin=(
             'and_('
@@ -400,7 +400,8 @@ class ShareInstance(BASE, ManilaBase):
 
     export_locations = orm.relationship(
         "ShareInstanceExportLocations",
-        lazy='immediate',
+        lazy='joined',
+        backref=orm.backref('share_instance', lazy='joined'),
         primaryjoin=(
             'and_('
             'ShareInstance.id == '
@@ -414,7 +415,7 @@ class ShareInstance(BASE, ManilaBase):
                              nullable=True)
     share_type = orm.relationship(
         "ShareTypes",
-        lazy='immediate',
+        lazy='subquery',
         foreign_keys=share_type_id,
         primaryjoin='and_('
                     'ShareInstance.share_type_id == ShareTypes.id, '
@@ -430,10 +431,14 @@ class ShareInstanceExportLocations(BASE, ManilaBase):
     @property
     def el_metadata(self):
         el_metadata = {}
-        for meta in self._el_metadata_bare:  # pylint: disable=E1101
+        for meta in self._el_metadata_bare:  # pylint: disable=no-member
             el_metadata[meta['key']] = meta['value']
         return el_metadata
 
+    @property
+    def replica_state(self):
+        return self.share_instance['replica_state']
+
     id = Column(Integer, primary_key=True)
     uuid = Column(String(36), nullable=False, unique=True)
     share_instance_id = Column(
@@ -467,7 +472,7 @@ class ShareInstanceExportLocationsMetadata(BASE, ManilaBase):
 
     @property
     def export_location_uuid(self):
-        return self.export_location.uuid  # pylint: disable=E1101
+        return self.export_location.uuid  # pylint: disable=no-member
 
 
 class ShareTypes(BASE, ManilaBase):
@@ -746,6 +751,14 @@ class ShareSnapshotInstance(BASE, ManilaBase):
         # with share drivers
         return self.share_instance_id
 
+    @property
+    def size(self):
+        # NOTE(silvacarlose) for backwards compatibility
+        if self.instance_size is None:
+            return self.snapshot.size
+        else:
+            return self.instance_size
+
     id = Column(String(36), primary_key=True)
     deleted = Column(String(36), default='False')
     snapshot_id = Column(String(36), nullable=True)
@@ -755,7 +768,7 @@ class ShareSnapshotInstance(BASE, ManilaBase):
     progress = Column(String(255))
     provider_location = Column(String(255))
     share_proto = Column(String(255))
-    size = Column(Integer)
+    instance_size = Column('size', Integer)
     share_group_snapshot_id = Column(String(36), nullable=True)
     user_id = Column(String(255))
     project_id = Column(String(255))
@@ -946,10 +959,15 @@ class ShareServer(BASE, ManilaBase):
     share_network_id = Column(String(36), ForeignKey('share_networks.id'),
                               nullable=True)
     host = Column(String(255), nullable=False)
-    status = Column(Enum(constants.STATUS_INACTIVE, constants.STATUS_ACTIVE,
-                         constants.STATUS_ERROR, constants.STATUS_DELETING,
-                         constants.STATUS_CREATING, constants.STATUS_DELETED),
-                    default=constants.STATUS_INACTIVE)
+    is_auto_deletable = Column(Boolean, default=True)
+    identifier = Column(String(255), nullable=True)
+    status = Column(Enum(
+        constants.STATUS_INACTIVE, constants.STATUS_ACTIVE,
+        constants.STATUS_ERROR, constants.STATUS_DELETING,
+        constants.STATUS_CREATING, constants.STATUS_DELETED,
+        constants.STATUS_MANAGING, constants.STATUS_UNMANAGING,
+        constants.STATUS_UNMANAGE_ERROR, constants.STATUS_MANAGE_ERROR),
+        default=constants.STATUS_INACTIVE)
     network_allocations = orm.relationship(
         "NetworkAllocation",
         primaryjoin='and_('
