@@ -833,7 +833,8 @@ class NeutronNetworkHelper(BaseNetworkhelper):
 
         if router_id and subnet_id:
             ports = self.neutron_api.list_ports(
-                fields=['fixed_ips', 'device_id', 'device_owner'])
+                fields=['device_id', 'device_owner'],
+                fixed_ips=['subnet_id=%s' % subnet_id])
             # NOTE(vponomaryov): iterate ports to get to know whether current
             # subnet is used or not. We will not remove it from router if it
             # is used.
@@ -843,12 +844,10 @@ class NeutronNetworkHelper(BaseNetworkhelper):
                 # we know that it is VM. We continue only if both are 'True'.
                 if (port['device_id'] and
                         port['device_owner'].startswith('compute:')):
-                    for fixed_ip in port['fixed_ips']:
-                        if fixed_ip['subnet_id'] == subnet_id:
-                            # NOTE(vponomaryov): There are other share servers
-                            # exist that use this subnet. So, do not remove it
-                            # from router.
-                            return
+                    # NOTE(vponomaryov): There are other share servers
+                    # exist that use this subnet. So, do not remove it
+                    # from router.
+                    return
             try:
                 # NOTE(vponomaryov): there is no other share servers or
                 # some VMs that use this subnet. So, remove it from router.
