@@ -34,6 +34,9 @@ class NetAppBaseClientTestCase(test.TestCase):
         self.mock_object(client_base.LOG,
                          'error',
                          mock.Mock(side_effect=mock_logger.error))
+        self.mock_object(client_base.LOG,
+                         'exception',
+                         mock.Mock(side_effect=mock_logger.error))
 
         self.client = client_base.NetAppBaseClient(**fake.CONNECTION_INFO)
         self.client.connection = mock.MagicMock()
@@ -63,10 +66,22 @@ class NetAppBaseClientTestCase(test.TestCase):
             fake.SYSTEM_GET_VERSION_RESPONSE)
         self.connection.invoke_successfully.return_value = version_response
 
+        result = self.client.get_system_version(cached=False)
+
+        self.assertEqual(fake.VERSION, result['version'])
+        self.assertEqual((8, 2, 1), result['version-tuple'])
+
+    def test_get_system_version_cached(self):
+
+        self.connection.get_system_version.return_value = {
+            'version': fake.VERSION,
+            'version-tuple': (8, 2, 1)
+        }
+
         result = self.client.get_system_version()
 
         self.assertEqual(fake.VERSION, result['version'])
-        self.assertEqual(('8', '2', '1'), result['version-tuple'])
+        self.assertEqual((8, 2, 1), result['version-tuple'])
 
     def test_init_features(self):
 
@@ -133,7 +148,7 @@ class NetAppBaseClientTestCase(test.TestCase):
                          mock.Mock(side_effect=netapp_api.NaApiError))
 
         self.assertRaises(netapp_api.NaApiError, self.client.get_licenses)
-        self.assertEqual(1, client_base.LOG.error.call_count)
+        self.assertEqual(1, client_base.LOG.exception.call_count)
 
     def test_send_ems_log_message(self):
 
